Tutorial — gcmpy documentation

# Tutorial

This page is a tutorial introduction to `gcmpy`. It begins with an overview of the workflow structure of the library, and then uses it to build sequentially more complicated network examples.

- Getting started
- Creating random networks from marginal data
- Creating random networks from empirical data
- Creating random networks using the split degree model
- Creating random networks from clique covers